@@ -16,6 +16,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "base/timer.h"
 #include "base/unixtime.h"
 #include "boxes/peers/edit_peer_info_box.h" // EditPeerInfoBox::Available.
+#include "boxes/peers/edit_forum_topic_box.h"
 #include "boxes/moderate_messages_box.h"
 #include "boxes/report_messages_box.h"
 #include "boxes/star_gift_box.h"
@@ -70,6 +71,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/controls/userpic_button.h"
 #include "ui/effects/animations.h"
 #include "ui/effects/outline_segments.h"
+#include "ui/effects/round_checkbox.h"
 #include "ui/empty_userpic.h"
 #include "ui/layers/generic_box.h"
 #include "ui/painter.h"
@@ -83,10 +85,14 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/widgets/labels.h"
 #include "ui/widgets/menu/menu_add_action_callback_factory.h"
 #include "ui/widgets/popup_menu.h"
+#include "ui/widgets/tooltip.h"
 #include "ui/wrap/fade_wrap.h"
 #include "window/themes/window_theme.h"
 #include "window/window_peer_menu.h"
 #include "window/window_session_controller.h"
+#include "ui/text/text_utilities.h"
+#include "ui/toast/toast.h"
+#include "boxes/sticker_set_box.h"
 #include "styles/style_boxes.h"
 #include "styles/style_chat_helpers.h"
 #include "styles/style_chat.h"
@@ -102,6 +108,41 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 namespace Info::Profile {
 namespace {
 
+class Userpic final
+	: public Ui::AbstractButton
+	, public Ui::AbstractTooltipShower {
+public:
+	Userpic(QWidget *parent, Fn<bool()> hasStories)
+	: Ui::AbstractButton(parent)
+	, _hasStories(std::move(hasStories)) {
+		installEventFilter(this);
+	}
+
+	QString tooltipText() const override {
+		return _hasStories() ? tr::lng_view_button_story(tr::now) : QString();
+	}
+
+	QPoint tooltipPos() const override {
+		return QCursor::pos();
+	}
+
+	bool tooltipWindowActive() const override {
+		return Ui::AppInFocus() && Ui::InFocusChain(window());
+	}
+
+protected:
+	bool eventFilter(QObject *obj, QEvent *e) override {
+		if (obj == this && e->type() == QEvent::Enter && _hasStories()) {
+			Ui::Tooltip::Show(1000, this);
+		}
+		return Ui::AbstractButton::eventFilter(obj, e);
+	}
+
+private:
+	Fn<bool()> _hasStories;
+
+};
+
 constexpr auto kWaitBeforeGiftBadge = crl::time(1000);
 constexpr auto kGiftBadgeGlares = 3;
 constexpr auto kMinPatternRadius = 8;
@@ -315,7 +356,12 @@ TopBar::TopBar(
 		}
 	});
 	return owned;
-}()) {
+}())
+, _backToggles(std::move(descriptor.backToggles)) {
+	_peer->updateFull();
+	if (const auto broadcast = _peer->monoforumBroadcast()) {
+		broadcast->updateFull();
+	}
 	const auto controller = descriptor.controller;
 
 	if (_peer->isMegagroup() || _peer->isChat()) {
@@ -369,26 +415,19 @@ TopBar::TopBar(
 			std::move(badgeUpdates),
 			_botVerify->updated());
 	}
+	_title->naturalWidthValue() | rpl::start_with_next([=](int w) {
+		_title->resizeToWidth(w);
+	}, _title->lifetime());
 	badgeUpdates = rpl::merge(
 		std::move(badgeUpdates),
-		nameValue() | rpl::map([=](const QString &name) {
-			const auto emojiCount = ranges::count(name, true, [](QChar ch) {
-				return ch.isHighSurrogate();
-			});
-			_title->resizeToWidth(_title->st().style.font->width(name)
-				+ emojiCount);
-			return rpl::empty_value();
-		}),
-		rpl::duplicate(descriptor.backToggles) | rpl::to_empty);
+		nameValue() | rpl::to_empty,
+		_backToggles.value() | rpl::to_empty);
 	std::move(badgeUpdates) | rpl::start_with_next([=] {
 		updateLabelsPosition();
 	}, _title->lifetime());
 
 	setupUniqueBadgeTooltip();
-	setupButtons(
-		controller,
-		rpl::duplicate(descriptor.backToggles),
-		descriptor.source);
+	setupButtons(controller, descriptor.source);
 	setupUserpicButton(controller);
 	if (_hasActions) {
 		_peer->session().changes().peerFlagsValue(
@@ -460,9 +499,12 @@ void TopBar::adjustColors(const std::optional<QColor> &edgeColor) {
 		return edgeColor
 			&& (kMinContrast > Ui::CountContrast(color->c, *edgeColor));
 	};
+	const auto collectible = effectiveCollectible();
 	const auto shouldOverrideTitle = shouldOverride(_title->st().textFg);
-	const auto shouldOverrideStatus = shouldOverride(_status->st().textFg);
-	_title->setTextColorOverride(shouldOverrideTitle
+	const auto shouldOverrideStatus = shouldOverrideTitle; // shouldOverride(_status->st().textFg);
+	_title->setTextColorOverride(collectible
+		? collectible->textColor
+		: shouldOverrideTitle
 		? std::optional<QColor>(st::groupCallMembersFg->c)
 		: std::nullopt);
 	if (!_showLastSeen->isHidden()) {
@@ -502,7 +544,9 @@ void TopBar::adjustColors(const std::optional<QColor> &edgeColor) {
 		}, _status->lifetime());
 		_statusLabel = std::make_unique<StatusLabel>(_status.data(), _peer);
 		_statusLabel->setMembersLinkCallback(membersLinkCallback);
-		_status->setTextColorOverride(shouldOverrideStatus
+		_status->setTextColorOverride(collectible
+			? collectible->textColor
+			: shouldOverrideStatus
 			? std::optional<QColor>(st::groupCallVideoSubTextFg->c)
 			: std::nullopt);
 		_statusLabel->setColorized(!shouldOverrideStatus);
@@ -559,10 +603,14 @@ void TopBar::updateCollectibleStatus() {
 		: _peer->profileBackgroundEmojiId();
 	if (patternEmojiId) {
 		const auto document = _peer->owner().document(patternEmojiId);
-		_patternEmoji = document->owner().customEmojiManager().create(
-			document,
-			[=] { update(); },
-			Data::CustomEmojiSizeTag::Normal);
+		if (!_patternEmoji
+			|| _patternEmoji->entityData()
+				!= Data::SerializeCustomEmojiId(document)) {
+			_patternEmoji = document->owner().customEmojiManager().create(
+				document,
+				[=] { update(); },
+				Data::CustomEmojiSizeTag::Normal);
+		}
 	} else {
 		_patternEmoji = nullptr;
 	}
@@ -700,10 +748,22 @@ void TopBar::setupActions(not_null<Window::SessionController*> controller) {
 			tr::lng_profile_action_short_join(tr::now),
 			st::infoProfileTopBarActionJoin);
 		join->setClickedCallback([=] {
-			channel->owner().session().api().joinChannel(channel);
+			channel->session().api().joinChannel(channel);
 		});
 		buttons.push_back(join);
 		_actions->add(join);
+	} else if (const auto channel = peer->monoforumBroadcast()) {
+		const auto message = Ui::CreateChild<TopBarActionButton>(
+			this,
+			tr::lng_profile_action_short_channel(tr::now),
+			st::infoProfileTopBarActionMessage);
+		message->setClickedCallback([=, window = controller] {
+			window->showPeerHistory(
+				channel,
+				Window::SectionShow::Way::Forward);
+		});
+		buttons.push_back(message);
+		_actions->add(message);
 	}
 	{
 		const auto notifications = Ui::CreateChild<TopBarActionButton>(
@@ -782,7 +842,7 @@ void TopBar::setupActions(not_null<Window::SessionController*> controller) {
 		&& user
 		&& !user->sharedMediaInfo()
 		&& !user->isInaccessible()
-		&& user->hasCalls()) {
+		&& user->callsStatus() != UserData::CallsStatus::Disabled) {
 		const auto call = Ui::CreateChild<TopBarActionButton>(
 			this,
 			tr::lng_profile_action_short_call(tr::now),
@@ -796,7 +856,8 @@ void TopBar::setupActions(not_null<Window::SessionController*> controller) {
 	if (chechMax()) {
 		return;
 	}
-	if (const auto chat = channel ? channel->discussionLink() : nullptr) {
+	if (const auto chat = channel ? channel->discussionLink() : nullptr;
+			chat && chat->isMegagroup()) {
 		const auto discuss = Ui::CreateChild<TopBarActionButton>(
 			this,
 			tr::lng_profile_action_short_discuss(tr::now),
@@ -817,13 +878,21 @@ void TopBar::setupActions(not_null<Window::SessionController*> controller) {
 	if (chechMax()) {
 		return;
 	}
-	if (EditPeerInfoBox::Available(peer)) {
+	if ((topic && topic->canEdit()) || EditPeerInfoBox::Available(peer)) {
 		const auto manage = Ui::CreateChild<TopBarActionButton>(
 			this,
 			tr::lng_profile_action_short_manage(tr::now),
 			st::infoProfileTopBarActionManage);
 		manage->setClickedCallback([=, window = controller] {
-			window->showEditPeerBox(peer);
+			if (topic) {
+				window->show(Box(
+					EditForumTopicBox,
+					window,
+					peer->owner().history(peer),
+					topic->rootId()));
+			} else {
+				window->showEditPeerBox(peer);
+			}
 		});
 		buttons.push_back(manage);
 		_actions->add(manage);
@@ -894,19 +963,9 @@ void TopBar::setupActions(not_null<Window::SessionController*> controller) {
 
 void TopBar::setupUserpicButton(
 		not_null<Window::SessionController*> controller) {
-	_userpicButton = base::make_unique_q<Ui::AbstractButton>(this);
-	rpl::single(
-		rpl::empty_value()
-	) | rpl::then(
-		_peer->session().changes().peerFlagsValue(
-			_peer,
-			Data::PeerUpdate::Flag::Photo) | rpl::to_empty
-	) | rpl::start_with_next([=] {
-		_userpicButton->setAttribute(
-			Qt::WA_TransparentForMouseEvents,
-			!_peer->userpicPhotoId() && !_hasStories);
-		updateVideoUserpic();
-	}, lifetime());
+	_userpicButton = base::make_unique_q<Userpic>(
+		this,
+		[=] { return _hasStories; });
 
 	const auto openPhoto = [=, peer = _peer] {
 		if (const auto id = peer->userpicPhotoId()) {
@@ -940,13 +999,22 @@ void TopBar::setupUserpicButton(
 		return true;
 	};
 
-	const auto isContact = [=, peer = _peer] {
+	const auto canChangePhoto = [=, peer = _peer] {
+		if (_topicIconView) {
+			return false;
+		}
 		if (const auto user = peer->asUser()) {
 			return user->isContact()
 				&& !user->isSelf()
 				&& !user->isInaccessible()
 				&& !user->isServiceUser();
 		}
+		if (const auto chat = peer->asChat()) {
+			return chat->canEditInformation();
+		}
+		if (const auto channel = peer->asChannel()) {
+			return channel->canEditInformation();
+		}
 		return false;
 	};
 
@@ -960,9 +1028,60 @@ void TopBar::setupUserpicButton(
 		return false;
 	};
 
-	const auto choosePhotoCallback = [=](Ui::UserpicButton::ChosenType type) {
+	const auto hasMenu = [=] {
+		if (canChangePhoto()) {
+			return true;
+		}
+		if (canSuggestPhoto()) {
+			return true;
+		}
+		if (_hasStories || canReport()) {
+			return !!_peer->userpicPhotoId();
+		}
+		return false;
+	};
+
+	const auto invalidate = [=] {
+		_userpicUniqueKey = InMemoryKey();
+		const auto hasLeftButton = _peer->userpicPhotoId() || _hasStories;
+		_userpicButton->setAttribute(
+			Qt::WA_TransparentForMouseEvents,
+			!hasLeftButton && !hasMenu());
+		_userpicButton->setPointerCursor(hasLeftButton);
+		updateVideoUserpic();
+		_peer->session().downloaderTaskFinished(
+		) | rpl::filter([=] {
+			return !Ui::PeerUserpicLoading(_userpicView);
+		}) | rpl::start_with_next([=] {
+			update();
+			_userpicLoadingLifetime.destroy();
+		}, _userpicLoadingLifetime);
+		Ui::PostponeCall(this, [=] {
+			update();
+		});
+	};
+
+	rpl::single(
+		rpl::empty_value()
+	) | rpl::then(
+		_peer->session().changes().peerFlagsValue(
+			_peer,
+			Data::PeerUpdate::Flag::Photo
+				| Data::PeerUpdate::Flag::FullInfo) | rpl::to_empty
+	) | rpl::start_with_next(invalidate, lifetime());
+
+	if (const auto broadcast = _peer->monoforumBroadcast()) {
+		_peer->session().changes().peerFlagsValue(
+			broadcast,
+			Data::PeerUpdate::Flag::Photo
+				| Data::PeerUpdate::Flag::FullInfo
+		) | rpl::to_empty | rpl::start_with_next(invalidate, lifetime());
+	}
+
+	using ChosenType = Ui::UserpicButton::ChosenType;
+
+	const auto choosePhotoCallback = [=](ChosenType type) {
 		return [=](QImage &&image) {
-			using ChosenType = Ui::UserpicButton::ChosenType;
 			auto result = Api::PeerPhoto::UserPhoto{
 				std::move(image),
 				0,
@@ -983,12 +1102,12 @@ void TopBar::setupUserpicButton(
 		};
 	};
 
-	const auto editorData = [=](Ui::UserpicButton::ChosenType type) {
+	const auto editorData = [=](ChosenType type) {
 		const auto user = _peer->asUser();
 		const auto name = (user && !user->firstName.isEmpty())
 			? user->firstName
 			: _peer->name();
-		const auto phrase = (type == Ui::UserpicButton::ChosenType::Suggest)
+		const auto phrase = (type == ChosenType::Suggest)
 			? &tr::lng_profile_suggest_sure
 			: &tr::lng_profile_set_personal_sure;
 		return Editor::EditorData{
@@ -997,7 +1116,7 @@ void TopBar::setupUserpicButton(
 				lt_user,
 				Ui::Text::Bold(name),
 				Ui::Text::WithEntities),
-			.confirm = ((type == Ui::UserpicButton::ChosenType::Suggest)
+			.confirm = ((type == ChosenType::Suggest)
 				? tr::lng_profile_suggest_button(tr::now)
 				: tr::lng_profile_set_photo_button(tr::now)),
 			.cropType = Editor::EditorData::CropType::Ellipse,
@@ -1005,7 +1124,7 @@ void TopBar::setupUserpicButton(
 		};
 	};
 
-	const auto chooseFile = [=](Ui::UserpicButton::ChosenType type) {
+	const auto chooseFile = [=](ChosenType type) {
 		base::call_delayed(
 			st::defaultRippleAnimation.hideDuration,
 			crl::guard(this, [=] {
@@ -1019,7 +1138,7 @@ void TopBar::setupUserpicButton(
 
 	const auto addFromClipboard = [=](
 			Ui::PopupMenu *menu,
-			Ui::UserpicButton::ChosenType type,
+			ChosenType type,
 			tr::phrase<> text) {
 		if (const auto data = QGuiApplication::clipboard()->mimeData()) {
 			if (data->hasImage()) {
@@ -1041,9 +1160,7 @@ void TopBar::setupUserpicButton(
 
 	_userpicButton->clicks() | rpl::start_with_next([=](
 			Qt::MouseButton button) {
-		if (button == Qt::RightButton
-			&& (_hasStories || canReport() || isContact())
-			&& _peer->userpicPhotoId()) {
+		if (button == Qt::RightButton && hasMenu()) {
 			*menu = base::make_unique_q<Ui::PopupMenu>(
 				this,
 				st::popupMenuWithIcons);
@@ -1068,32 +1185,48 @@ void TopBar::setupUserpicButton(
 					&st::menuIconReport);
 			}
 
-			if (isContact()) {
+			if (canChangePhoto()) {
 				if (!(*menu)->empty()) {
 					(*menu)->addSeparator(&st::expandedMenuSeparator);
 				}
-				(*menu)->addAction(
-					tr::lng_profile_set_photo_for(tr::now),
-					[=] { chooseFile(Ui::UserpicButton::ChosenType::Set); },
-					&st::menuIconPhotoSet);
-				addFromClipboard(
-					menu->get(),
-					Ui::UserpicButton::ChosenType::Set,
-					tr::lng_profile_set_photo_for_from_clipboard);
-				if (canSuggestPhoto()) {
+				const auto isUser = _peer->asUser();
+				if (isUser) {
 					(*menu)->addAction(
-						tr::lng_profile_suggest_photo(tr::now),
-						[=] {
-							chooseFile(
-								Ui::UserpicButton::ChosenType::Suggest);
-						},
-						&st::menuIconPhotoSuggest);
+						tr::lng_profile_set_photo_for(tr::now),
+						[=] { chooseFile(ChosenType::Set); },
+						&st::menuIconPhotoSet);
 					addFromClipboard(
 						menu->get(),
-						Ui::UserpicButton::ChosenType::Suggest,
-						tr::lng_profile_suggest_photo_from_clipboard);
+						ChosenType::Set,
+						tr::lng_profile_set_photo_for_from_clipboard);
+					if (canSuggestPhoto()) {
+						(*menu)->addAction(
+							tr::lng_profile_suggest_photo(tr::now),
+							[=] {
+								chooseFile(
+									ChosenType::Suggest);
+							},
+							&st::menuIconPhotoSuggest);
+						addFromClipboard(
+								menu->get(),
+								ChosenType::Suggest,
+								tr::lng_profile_suggest_photo_from_clipboard);
+					}
+				} else {
+					const auto channel = _peer->asChannel();
+					const auto isChannel = channel && !channel->isMegagroup();
+					(*menu)->addAction(
+						isChannel
+							? tr::lng_profile_set_photo_for_channel(tr::now)
+							: tr::lng_profile_set_photo_for_group(tr::now),
+						[=] { chooseFile(ChosenType::Set); },
+						&st::menuIconPhotoSet);
+					addFromClipboard(
+						menu->get(),
+						ChosenType::Set,
+						tr::lng_profile_set_photo_for_from_clipboard);
 				}
-				if (controller) {
+				if (controller && isUser) {
 					const auto done = [=](UserpicBuilder::Result data) {
 						auto result = Api::PeerPhoto::UserPhoto{
 							base::take(data.image),
@@ -1113,10 +1246,43 @@ void TopBar::setupUserpicButton(
 						false);
 				}
 			}
-
-			(*menu)->popup(QCursor::pos());
+			if (!(*menu)->empty()) {
+				(*menu)->popup(QCursor::pos());
+			}
 		} else if (button == Qt::LeftButton) {
-			if (_hasStories) {
+			if (_topicIconView && _topic && _topic->iconId()) {
+				const auto document = _peer->owner().document(
+					_topic->iconId());
+				if (const auto sticker = document->sticker()) {
+					const auto packName
+						= _peer->owner().customEmojiManager().lookupSetName(
+							sticker->set.id);
+					if (!packName.isEmpty()) {
+						const auto text = tr::lng_profile_topic_toast(
+							tr::now,
+							lt_name,
+							Ui::Text::Link(packName, u"internal:"_q),
+							Ui::Text::WithEntities);
+						const auto weak = base::make_weak(controller);
+						controller->showToast(Ui::Toast::Config{
+							.text = text,
+							.filter = [=, set = sticker->set](
+									const ClickHandlerPtr &handler,
+									Qt::MouseButton) {
+								if (const auto strong = weak.get()) {
+									strong->show(
+										Box<StickerSetBox>(
+											strong->uiShow(),
+											set,
+											Data::StickersType::Emoji));
+								}
+								return false;
+							},
+							.duration = crl::time(3000),
+						});
+					}
+				}
+			} else if (_hasStories) {
 				controller->openPeerStories(_peer->id);
 			} else {
 				openPhoto();
@@ -1126,7 +1292,7 @@ void TopBar::setupUserpicButton(
 }
 
 void TopBar::setupUniqueBadgeTooltip() {
-	if (!_badge) {
+	if (!_badge || _source == Source::Preview) {
 		return;
 	}
 	base::timer_once(kWaitBeforeGiftBadge) | rpl::then(
@@ -1223,7 +1389,7 @@ void TopBar::setPatternEmojiId(std::optional<DocumentId> patternEmojiId) {
 
 void TopBar::setLocalEmojiStatusId(EmojiStatusId emojiStatusId) {
 	_localCollectible = emojiStatusId.collectible;
-	if (emojiStatusId) {
+	if (!emojiStatusId.collectible) {
 		_badgeContent = Badge::Content{ BadgeType::Premium, emojiStatusId };
 	} else {
 		_badgeContent = BadgeContentForPeer(_peer);
@@ -1244,6 +1410,8 @@ auto TopBar::effectiveCollectible() const
 -> std::shared_ptr<Data::EmojiStatusCollectible> {
 	return _localCollectible
 		? _localCollectible
+		: _localColorProfileIndex
+		? nullptr
 		: _peer->emojiStatusId().collectible;
 }
 
@@ -1283,7 +1451,21 @@ int TopBar::statusMostLeft() const {
 		: _st.subtitlePosition.x();
 }
 
+int TopBar::calculateRightButtonsWidth() const {
+	auto width = 0;
+	if (_close) {
+		width += _close->width();
+	}
+	if (_topBarButton) {
+		width += _topBarButton->width();
+	}
+	return width;
+}
+
 void TopBar::updateLabelsPosition() {
+	if (width() <= 0) {
+		return;
+	}
 	_progress = [&] {
 		const auto max = QWidget::maximumHeight();
 		const auto min = _minForProgress;
@@ -1294,13 +1476,7 @@ void TopBar::updateLabelsPosition() {
 	}();
 	const auto progressCurrent = _progress.current();
 
-	auto rightButtonsWidth = 0;
-	if (_close) {
-		rightButtonsWidth += _close->width();
-	}
-	if (_topBarButton) {
-		rightButtonsWidth += _topBarButton->width();
-	}
+	const auto rightButtonsWidth = calculateRightButtonsWidth();
 
 	const auto reservedRight = anim::interpolate(
 		0,
@@ -1311,22 +1487,26 @@ void TopBar::updateLabelsPosition() {
 		titleMostLeft,
 		rect::m::sum::h(st::boxRowPadding),
 		progressCurrent);
-	auto titleWidth = width() - interpolatedPadding - reservedRight;
 	const auto verifiedWidget = _verified ? _verified->widget() : nullptr;
 	const auto badgeWidget = _badge ? _badge->widget() : nullptr;
 	const auto botVerifyWidget = _botVerify ? _botVerify->widget() : nullptr;
+	auto badgesWidth = 0;
 	if (verifiedWidget) {
-		titleWidth -= verifiedWidget->width();
+		badgesWidth += verifiedWidget->width();
 	}
 	if (badgeWidget) {
-		titleWidth -= badgeWidget->width();
+		badgesWidth += badgeWidget->width();
 	}
 	if (botVerifyWidget) {
-		titleWidth -= botVerifyWidget->width();
+		badgesWidth += botVerifyWidget->width();
 	}
 	if (verifiedWidget || badgeWidget) {
-		titleWidth -= st::infoVerifiedCheckPosition.x();
+		badgesWidth += st::infoVerifiedCheckPosition.x();
 	}
+	const auto titleWidth = width()
+		- interpolatedPadding
+		- reservedRight
+		- badgesWidth;
 
 	if (titleWidth > 0 && _title->textMaxWidth() > titleWidth) {
 		_title->resizeToWidth(titleWidth);
@@ -1398,13 +1578,29 @@ void TopBar::updateLabelsPosition() {
 }
 
 void TopBar::updateStatusPosition(float64 progressCurrent) {
+	if (width() <= 0) {
+		return;
+	}
 	if (_forumButton) {
 		const auto buttonTop = anim::interpolate(
 			_st.subtitlePosition.y(),
 			st::infoProfileTopBarStatusTop,
 			progressCurrent);
+		const auto mostLeft = statusMostLeft();
+		const auto buttonMostLeft = anim::interpolate(
+			mostLeft,
+			st::infoProfileTopBarActionButtonsPadding.left(),
+			progressCurrent);
+		const auto buttonMostRight = anim::interpolate(
+			calculateRightButtonsWidth(),
+			st::infoProfileTopBarActionButtonsPadding.right(),
+			progressCurrent);
+		const auto maxWidth = width() - buttonMostLeft - buttonMostRight;
+		if (_forumButton->contentWidth() > maxWidth) {
+			_forumButton->setFullWidth(maxWidth);
+		}
 		const auto buttonLeft = anim::interpolate(
-			statusMostLeft(),
+			mostLeft,
 			(width() - _forumButton->width()) / 2,
 			progressCurrent);
 		_forumButton->moveToLeft(buttonLeft, buttonTop);
@@ -1483,6 +1679,9 @@ QRect TopBar::userpicGeometry() const {
 void TopBar::updateGiftButtonsGeometry(
 		float64 progressCurrent,
 		const QRect &userpicRect) {
+	if (width() <= 0) {
+		return;
+	}
 	const auto sz = st::infoProfileTopBarGiftSize;
 	const auto halfSz = sz / 2.;
 	for (const auto &gift : _pinnedToTopGifts) {
@@ -1622,7 +1821,6 @@ void TopBar::paintEvent(QPaintEvent *e) {
 
 void TopBar::setupButtons(
 		not_null<Window::SessionController*> controller,
-		rpl::producer<bool> backToggles,
 		Source source) {
 	if (source == Source::Preview) {
 		setRoundEdges(false);
@@ -1631,7 +1829,7 @@ void TopBar::setupButtons(
 	rpl::combine(
 		_wrap.value(),
 		_edgeColor.value()
-	) | rpl::start_with_next([=, backToggles = std::move(backToggles)](
+	) | rpl::start_with_next([=](
 			Wrap wrap,
 			std::optional<QColor> edgeColor) mutable {
 		const auto isLayer = (wrap == Wrap::Layer);
@@ -1658,7 +1856,7 @@ void TopBar::setupButtons(
 		_back->QWidget::show();
 		_back->setDuration(0);
 		_back->toggleOn(isLayer || isSide
-			? rpl::duplicate(backToggles)
+			? (_backToggles.value() | rpl::type_erased())
 			: rpl::single(wrap == Wrap::Narrow));
 		_back->entity()->clicks() | rpl::to_empty | rpl::start_to_stream(
 			_backClicks,
@@ -1779,6 +1977,9 @@ void TopBar::fillTopBarMenu(
 }
 
 void TopBar::updateVideoUserpic() {
+	if (width() <= 0) {
+		return;
+	}
 	const auto id = _peer->userpicPhotoId();
 	if (!id) {
 		_videoUserpicPlayer = nullptr;
@@ -2310,7 +2511,8 @@ void TopBar::paintPinnedToTopGifts(
 
 void TopBar::setupStoryOutline(const QRect &geometry) {
 	const auto user = _peer->asUser();
-	if (!user) {
+	const auto channel = _peer->asChannel();
+	if (!user && !channel) {
 		return;
 	}
 
@@ -2319,18 +2521,18 @@ void TopBar::setupStoryOutline(const QRect &geometry) {
 		rpl::merge(
 			rpl::single(rpl::empty_value()),
 			style::PaletteChanged(),
-			user->session().changes().peerUpdates(
+			_peer->session().changes().peerUpdates(
 				Data::PeerUpdate::Flag::StoriesState
 					| Data::PeerUpdate::Flag::ColorProfile
 			) | rpl::filter([=](const Data::PeerUpdate &update) {
-				return update.peer == user;
+				return update.peer == _peer;
 			}) | rpl::to_empty)
 	) | rpl::start_with_next([=](
 			std::optional<QColor> edgeColor,
 			rpl::empty_value) {
 		const auto geometry = QRectF(userpicGeometry());
 		const auto colorProfile
-			= user->session().api().peerColors().colorProfileFor(user);
+			= _peer->session().api().peerColors().colorProfileFor(_peer);
 		const auto hasProfileColor = colorProfile
 			&& colorProfile->story.size() > 1;
 		if (hasProfileColor) {
@@ -2347,17 +2549,26 @@ void TopBar::setupStoryOutline(const QRect &geometry) {
 }
 
 void TopBar::updateStoryOutline(std::optional<QColor> edgeColor) {
+	if (width() <= 0) {
+		return;
+	}
 	const auto user = _peer->asUser();
-	if (!user) {
+	const auto channel = _peer->asChannel();
+	if (!user && !channel) {
 		return;
 	}
 
 	const auto hasActiveStories = (_source == Source::Preview)
 		? true
-		: user->hasActiveStories();
+		: (user ? user->hasActiveStories() : channel->hasActiveStories());
+	const auto hasLiveStories = (_source == Source::Preview)
+		? false
+		: (user ? user->hasActiveVideoStream() : false);
 
-	if (_hasStories != hasActiveStories) {
+	if (_hasStories != hasActiveStories
+		|| _hasLiveStories != hasLiveStories) {
 		_hasStories = hasActiveStories;
+		_hasLiveStories = hasLiveStories;
 		update();
 	}
 
@@ -2391,8 +2602,8 @@ void TopBar::updateStoryOutline(std::optional<QColor> edgeColor) {
 		return;
 	}
 
-	const auto &stories = user->owner().stories();
-	const auto source = stories.source(user->id);
+	const auto &stories = _peer->owner().stories();
+	const auto source = stories.source(_peer->id);
 	if (!source) {
 		return;
 	}
@@ -2400,21 +2611,30 @@ void TopBar::updateStoryOutline(std::optional<QColor> edgeColor) {
 	const auto baseColor = edgeColor
 		? Ui::BlendColors(*edgeColor, Qt::white, .5)
 		: _storyOutlineBrush.color();
-	const auto unreadBrush = edgeColor
+	const auto unreadBrush = _hasLiveStories
+		? st::attentionButtonFg->b
+		: edgeColor
 		? QBrush(baseColor)
 		: _storyOutlineBrush;
 	const auto readBrush = edgeColor
 		? QBrush(anim::with_alpha(baseColor, 0.5))
 		: QBrush(st::dialogsUnreadBgMuted->b);
 
-	const auto readTill = source->readTill;
-	const auto widthSmall = widthBig / 2.;
-	for (const auto &storyIdDates : source->ids) {
-		const auto isUnread = (storyIdDates.id > readTill);
+	if (_hasLiveStories) {
 		_storySegments.push_back({
-			.brush = isUnread ? unreadBrush : readBrush,
-			.width = !isUnread ? widthSmall : widthBig,
+			.brush = unreadBrush,
+			.width = widthBig,
 		});
+	} else {
+		const auto readTill = source->readTill;
+		const auto widthSmall = widthBig / 2.;
+		for (const auto &storyIdDates : source->ids) {
+			const auto isUnread = (storyIdDates.id > readTill);
+			_storySegments.push_back({
+				.brush = isUnread ? unreadBrush : readBrush,
+				.width = !isUnread ? widthSmall : widthBig,
+			});
+		}
 	}
 }
 
@@ -2443,6 +2663,17 @@ void TopBar::paintStoryOutline(QPainter &p, const QRect &geometry) {
 		padding + outlineWidth / 2);
 
 	Ui::PaintOutlineSegments(p, outlineRect, _storySegments);
+
+	if (_hasLiveStories) {
+		const auto outline = _edgeColor.current().value_or(
+			_solidBg.value_or(st::boxDividerBg->c));
+		Ui::PaintLiveBadge(
+			p,
+			geometry.x(),
+			geometry.y() + outlineWidth + padding,
+			geometry.width(),
+			outline);
+	}
 }
 
 void TopBar::setupStatusWithRating() {
