@@ -167,8 +167,12 @@ bool AbstractButton::setDown(
 		&& (_acceptBoth || button == Qt::LeftButton)) {
 		auto was = _state;
 		_state |= StateFlag::Down;
+
+		const auto weak = base::make_weak(this);
 		onStateChanged(was, source);
-		accessibilityStateChanged({ .pressed = true });
+		if (weak) {
+			accessibilityStateChanged({ .pressed = true });
+		}
 		return true;
 	} else if (!down && (_state & StateFlag::Down)) {
 		const auto was = _state;
@@ -176,8 +180,8 @@ bool AbstractButton::setDown(
 
 		const auto weak = base::make_weak(this);
 		onStateChanged(was, source);
-		accessibilityStateChanged({ .pressed = true });
 		if (weak) {
+			accessibilityStateChanged({ .pressed = true });
 			if (was & StateFlag::Over) {
 				clicked(modifiers, button);
 			} else {
@@ -218,4 +222,12 @@ AccessibilityState AbstractButton::accessibilityState() const {
 	return { .pressed = isDown() };
 	}
 
+void AbstractButton::accessibilityDoAction(const QString &name) {
+	if (name == QAccessibleActionInterface::pressAction()) {
+		if (!isDisabled()) {
+			clicked(Qt::NoModifier, Qt::LeftButton);
+		}
+	}
+}
+
 } // namespace Ui
