@@ -53,6 +53,7 @@ public:
 	[[nodiscard]] rpl::producer<not_null<QScreen*>> screenValue() const;
 	[[nodiscard]] rpl::producer<bool> windowActiveValue() const;
 	[[nodiscard]] rpl::producer<QRect> paintRequest() const;
+	void paintOn(Fn<void(QPainter&)> callback);
 	[[nodiscard]] rpl::producer<> alive() const;
 	[[nodiscard]] rpl::producer<> death() const;
 	[[nodiscard]] rpl::producer<> macWindowDeactivateEvents() const;
@@ -355,6 +356,7 @@ private:
 struct AccessibilityState {
 	bool checkable : 1 = false;
 	bool checked : 1 = false;
+	bool pressed : 1 = false;
 
 	void writeTo(QAccessible::State &state);
 };
@@ -390,6 +392,8 @@ public:
 	void accessibilityStateChanged(AccessibilityState changes);
 	[[nodiscard]] virtual QString accessibilityValue() const;
 	void accessibilityValueChanged();
+	[[nodiscard]] virtual QStringList accessibilityActionNames();
+	virtual void accessibilityDoAction(const QString &name);
 
 protected:
 	// e - from enterEvent() of child RpWidget
