@@ -368,6 +368,11 @@ void RoundButton::setTextFgOverride(std::optional<QColor> textFg) {
 	update();
 }
 
+void RoundButton::setIconOverride(const style::icon *icon) {
+	_iconOverride = icon;
+	update();
+}
+
 void RoundButton::finishNumbersAnimation() {
 	if (_numbers) {
 		_numbers->finishAnimating();
@@ -519,9 +524,14 @@ void RoundButton::paintEvent(QPaintEvent *e) {
 		} else {
 			p.setPen((over || down) ? _st.textFgOver : _st.textFg);
 		}
+		auto local = st::defaultTextPalette;
+		local.linkFg = (over || down)
+			? _st.numbersTextFgOver
+			: _st.numbersTextFg;
 		_text.draw(p, {
 			.position = { textLeft, textTop },
 			.availableWidth = widthForText,
+			.palette = &local,
 			.elisionLines = 1,
 		});
 	}
@@ -532,7 +542,9 @@ void RoundButton::paintEvent(QPaintEvent *e) {
 		_numbers->paint(p, textLeft, textTop, width());
 	}
 	if (!_st.icon.empty()) {
-		const auto &current = ((over || down) && !_st.iconOver.empty())
+		const auto &current = _iconOverride
+			? *_iconOverride
+			: ((over || down) && !_st.iconOver.empty())
 			? _st.iconOver
 			: _st.icon;
 		current.paint(p, QPoint(iconLeft, iconTop), width());
@@ -565,11 +577,6 @@ IconButton::IconButton(QWidget *parent, const style::IconButton &st) : RippleBut
 	resize(_st.width, _st.height);
 }
 
-void IconButton::accessibilitySetName(QString name) {
-	_accessibilityName = std::move(name);
-	accessibilityNameChanged();
-}
-
 const style::IconButton &IconButton::st() const {
 	return _st;
 }
