@@ -606,7 +606,7 @@ void Checkbox::resizeToText() {
 void Checkbox::setChecked(bool checked, NotifyAboutChange notify) {
 	if (_check->checked() != checked) {
 		_check->setChecked(checked, anim::type::normal);
-		accessibilityStateChanged({ .checked = checked });
+		accessibilityStateChanged({ .checked = true });
 		if (notify == NotifyAboutChange::Notify) {
 			_checkedChanges.fire_copy(checked);
 		}
@@ -1065,6 +1065,14 @@ AccessibilityState Checkbox::accessibilityState() const {
 	return { .checkable = true, .checked = checked() };
 }
 
+void Checkbox::accessibilityDoAction(const QString &name) {
+	if (name == QAccessibleActionInterface::pressAction()) {
+		if (!isDisabled()) {
+			handlePress();
+		}
+	}
+}
+
 bool Checkbox::isSubmitEvent(not_null<QKeyEvent*> e) const {
 	return !e->isAutoRepeat()
 		&& (e->key() == Qt::Key_Space
